@@ -22,6 +22,19 @@ from optparse import OptionParser
 import genshi.core
 import ConfigParser
 
+
+# i18n
+from lazygal import INSTALL_MODE, INSTALL_PREFIX
+if INSTALL_MODE == 'source':
+    LOCALES_PATH = os.path.normpath(os.path.join(os.path.dirname(__file__),
+                                                 'build', 'mo'))
+elif INSTALL_MODE == 'installed':
+    LOCALES_PATH = os.path.join(INSTALL_PREFIX, 'share', 'locale')
+gettext.install('lazygal', LOCALES_PATH, unicode=1)
+
+locale.setlocale(locale.LC_ALL, locale.getdefaultlocale())
+
+
 import lazygal
 from lazygal.generators import Album, SOURCEDIR_CONFIGFILE
 from lazygal.genmedia import THUMB_SIZE_NAME
@@ -52,15 +65,6 @@ CONFIGDEFAULTS = {
     'template-vars': '',
 }
 
-# i18n
-LOCALES_PATH = os.path.normpath(os.path.join(os.path.dirname(__file__),
-                                             'build', 'mo'))
-if not os.path.exists(LOCALES_PATH):
-    LOCALES_PATH = '/usr/share/locale'
-gettext.install('lazygal', LOCALES_PATH, unicode=1)
-
-locale.setlocale(locale.LC_ALL, locale.getdefaultlocale())
-
 
 # Read configuration file
 config = ConfigParser.ConfigParser(defaults = CONFIGDEFAULTS)
@@ -119,12 +123,12 @@ parser.add_option("", "--dir-flattening-depth",
                   action="store", type="int",
                   dest="dir_flattening_depth",
                   default=config.getboolean('lazygal', 'dir-flattening-depth'),
-                  help=_("Level below witch the directory tree is flattened. Default is 0 which is unlimited."))
+                  help=_("Level below which the directory tree is flattened. Default is 'No' which disables this feature."))
 parser.add_option("-s", "--image-size",
                   action="store", type="string",
                   dest="image_size",
                   default=config.get('lazygal', 'image-size'),
-                  help=_("Size of images, define as <name>=SIZE,..., eg. small=800x600,medium=1024x768. The special dimensions 0x0 use original size. See manual page for SIZE syntax."))
+                  help=_("Size of images, define as <name>=SIZE,..., eg. small=800x600,medium=1024x768. The special value 0x0 uses original size. See manual page for SIZE syntax."))
 parser.add_option("-T", "--thumbnail-size",
                   action="store", type="string",
                   dest="thumbnail_size",
@@ -147,12 +151,12 @@ parser.add_option("", "--orig-base",
 parser.add_option("", "--orig-symlink",
                   action="store_true",
                   dest="orig_symlink",
-                  default=config.get('lazygal', 'orig-symlink'),
+                  default=config.getboolean('lazygal', 'orig-symlink'),
                   help=_("Do not copy original photos in output directory, instead create symlinks to their original locations."))
 parser.add_option("", "--puburl",
                   action="store", type="string",
                   dest="pub_url",
-                  help=_("Publication URL (only usefull for feed generation)."))
+                  help=_("Publication URL (only useful for feed generation)."))
 parser.add_option("-m", "--generate-metadata",
                   action="store_true",
                   dest="metadata", default=False,
@@ -174,7 +178,7 @@ parser.add_option("", "--webalbum-pic-bg",
 parser.add_option("", "--optimize",
                   action="store_true",
                   dest="optimize", default=config.getboolean('lazygal', 'optimize'),
-                  help=_("Run an extra optimization pass an each image."))
+                  help=_("Run an extra optimization pass on each image."))
 parser.add_option("", "--progressive",
                   action="store_true",
                   dest="progressive", default=config.getboolean('lazygal', 'progressive'),
