@@ -22,6 +22,20 @@ __all__ = [
         'generators',
         ]
 
+
+# Compute installation prefix
+if os.path.isfile(os.path.join(os.path.dirname(__file__), '..', 'setup.py')):
+    INSTALL_MODE = 'source'
+    INSTALL_PREFIX = ''
+else:
+    # Lazygal is installed, assume we are in
+    # $prefix/lib/python2.X/dist-packages/lazygal
+    INSTALL_MODE = 'installed'
+    INSTALL_PREFIX = os.path.join(os.path.dirname(__file__),
+                                  '..', '..', '..', '..')
+    INSTALL_PREFIX = os.path.normpath(INSTALL_PREFIX)
+
+
 def get_hg_rev():
     try:
         lazygal_dir = os.path.join(os.path.dirname(__file__), '..')
@@ -41,7 +55,7 @@ def get_hg_rev():
         return ''
 
 
-__version__ = '0.6'
+__version__ = '0.6.1'
 
 hg_rev = get_hg_rev()
 if hg_rev: __version__ += '+hg' + hg_rev
