@@ -27,11 +27,15 @@ import genpage, genmedia, genfile
 from sourcetree import SOURCEDIR_CONFIGFILE
 
 
-DATAPATH = os.path.normpath(os.path.join(os.path.dirname(__file__), '..'))
-if not os.path.exists(os.path.join(DATAPATH, 'themes')):
-    DATAPATH = os.path.join(sys.exec_prefix, 'share', 'lazygal')
+from lazygal import INSTALL_MODE, INSTALL_PREFIX
+if INSTALL_MODE == 'source':
+    DATAPATH = os.path.normpath(os.path.join(os.path.dirname(__file__), '..'))
+elif INSTALL_MODE == 'installed':
+    DATAPATH = os.path.join(INSTALL_PREFIX, 'share', 'lazygal')
     if not os.path.exists(os.path.join(DATAPATH, 'themes')):
         print _('Could not find themes dir, check your installation!')
+        sys.exit(1)
+
 
 THEME_DIR = os.path.join(DATAPATH, 'themes')
 USER_THEME_DIR = os.path.expanduser(os.path.join('~', '.lazygal', 'themes'))
@@ -150,7 +154,7 @@ class SubgalBreak(make.MakeTask):
 
     def __fill_real_pagination(self):
         how_many_pages = len(self.webgal_dir.medias)\
-                          / self.webgal_dir.album.thumbs_per_page + 1
+                          // self.webgal_dir.album.thumbs_per_page + 1
         for page_number in range(0, how_many_pages):
             step = page_number * self.webgal_dir.album.thumbs_per_page
             end_index = step + self.webgal_dir.album.thumbs_per_page
@@ -646,13 +650,39 @@ class Album:
             head, tail = os.path.split(head)
         return False
 
+    def walk(self, top, walked=None):
+        '''
+        This is a wrapper around os.walk() from the standard library:
+        - browsing with topdown=False
+        - following symbolic links on directories
+        - whith barriers in place against walking twice the same directory,
+          which may happen when two directory trees have symbolic links to
+          each other's contents.
+        '''
+        if walked is None: walked = []
+
+        for root, dirs, files in os.walk(top, topdown=False):
+            walked.append(os.path.realpath(root))
+
+            # Follow symlinks if they have not been walked yet
+            for d in dirs:
+                d_path = os.path.join(root, d)
+                if os.path.islink(d_path):
+                    if os.path.realpath(d_path) not in walked:
+                        for x in self.walk(d_path, walked):
+                            yield x
+                    else:
+                        self.log(_("Not following symlink '%s' because directory has already been processed.") % d_path, 'error')
+
+            yield root, dirs, files
+
     def generate_default_metadata(self):
         '''
         Generate default metada files if no exists.
         '''
         self.log(_("Generating metadata in %s") % self.source_dir)
 
-        for root, dirnames, filenames in os.walk(self.source_dir):
+        for root, dirnames, filenames in self.walk(self.source_dir):
             filenames.sort() # This is required for the ignored files
                              # checks to be reliable.
             source_dir = sourcetree.Directory(root, [], filenames, self)
@@ -678,10 +708,9 @@ class Album:
             feed = None
 
         dir_heap = {}
-        for root, dirnames, filenames in os.walk(self.source_dir,
-                                                 topdown=False):
+        for root, dirnames, filenames in self.walk(self.source_dir):
 
-            if dir_heap.has_key(root):
+            if root in dir_heap:
                 subdirs, subgals = dir_heap[root]
                 del dir_heap[root] # No need to keep it there
             else:
@@ -712,7 +741,7 @@ class Album:
 
             if not source_dir.is_album_root():
                 container_dirname = os.path.dirname(root)
-                if not dir_heap.has_key(container_dirname):
+                if container_dirname not in dir_heap:
                     dir_heap[container_dirname] = ([], [])
                 container_subdirs, container_subgals = dir_heap[container_dirname]
                 container_subdirs.append(source_dir)
