@@ -283,6 +283,7 @@ class WebalbumImagePage(WebalbumBrowsePage):
                 tpl_values['comment'] = None
             else:
                 tpl_values['comment'] = self._do_not_escape(comment)
+            tpl_values['authorship'] = image_info.get_authorship()
 
 
 class WebalbumVideoPage(WebalbumBrowsePage):
@@ -498,7 +499,7 @@ class SharedFileTemplate(make.FileMakeObject):
         if ext.startswith('.t'):
             self.path = filename + '.' + ext[2:]
         else:
-            raise ValueError(_('We have a template with an extension that does not start with a t. Abording.'))
+            raise ValueError(_('We have a template with an extension that does not start with a t. Aborting.'))
 
         make.FileMakeObject.__init__(self, self.path)
         self.add_file_dependency(shared_tpl_name)
