@@ -1,5 +1,5 @@
 # Lazygal, a lazy satic web gallery generator.
-# Copyright (C) 2010 Alexandre Rossi <alexandre.rossi@gmail.com>
+# Copyright (C) 2010-2011 Alexandre Rossi <alexandre.rossi@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -180,7 +180,7 @@ class OggTheoraTranscoder(GstVideoConverter):
 
 if __name__ == '__main__':
     import sys, os
-    converter = OggTheoraConverter()
+    converter = OggTheoraTranscoder()
     for file_path in sys.argv[1:]:
         fn, ext = os.path.splitext(file_path)
         ogg_path = fn + '.ogg'
